@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
 
-import whatthepatch as wtp
-from whatthepatch.patch import Change, diffobj, header as headerobj
-
-
-import unittest
 import os
+import time
+import unittest
+
+from src import whatthepatch as wtp
+from src.whatthepatch.patch import Change, diffobj
+from src.whatthepatch.patch import header as headerobj
 
 module_path = os.path.dirname(__file__)
 
@@ -20,7 +21,11 @@ def indent(amount, changes):
 
 
 CSC_CHANGES = [
-    (None, 1, "# This is a basic script I wrote to run Bugxplore over the dataset",),
+    (
+        None,
+        1,
+        "# This is a basic script I wrote to run Bugxplore over the dataset",
+    ),
     (None, 2, ""),
     (None, 3, ""),
     (1, 4, "import os"),
@@ -1420,6 +1425,30 @@ class PatchTestSuite(unittest.TestCase):
         results = list(wtp.patch.parse_patch(text))
         self.assertEqual(results[0].header, expected_header)
 
+    def test_huge_patch(self):
+        start_time = time.time()
+        text = """diff --git a/huge.file b/huge.file
+index 0000000..1111111 100644
+--- a/huge.file
++++ a/huge.file
+@@ -3,13 +3,1000007 @@
+ 00000000
+ 11111111
+ 22222222
+-33333333
+-44444444
++55555555
++66666666
+"""
+        for n in range(0, 1000000):
+            text += "+" + hex(n) + "\n"
+        result = list(wtp.patch.parse_patch(text))
+        self.assertEqual(1, len(result))
+        self.assertEqual(1000007, len(result[0].changes))
+        # This is 2x the usual time for CI to allow for some slow tests
+        # Really all we care about is that this parses faster than it used to (200s+)
+        self.assertGreater(20, time.time() - start_time)
+
 
 if __name__ == "__main__":
     unittest.main()
